==> haskell-monoid-subclasses-0.4.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monoid-subclasses
version: 0.4.3.1
id: monoid-subclasses-0.4.3.1-66jShhVzrLEHzXyBMv9poJ
key: monoid-subclasses-0.4.3.1-66jShhVzrLEHzXyBMv9poJ
license: BSD3
copyright: (c) 2013-2016 Mario Blazevic
maintainer: Mario Blazevic <blamario@yahoo.com>
homepage: https://github.com/blamario/monoid-subclasses/
synopsis: Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.
category: Data, Algebra, Text
author: Mario Blazevic
exposed: True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.Null
    Data.Monoid.Textual Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.Concat Data.Monoid.Instances.Measured
    Data.Monoid.Instances.Positioned Data.Monoid.Instances.Stateful
abi: 8a3ab737a507289afae12167ee620a65
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/monoid-subclasses-0.4.3.1
hs-libraries: HSmonoid-subclasses-0.4.3.1-66jShhVzrLEHzXyBMv9poJ
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    primes-0.2.1.0-K0eIDQpwpli2u6M20VlfZn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock
haddock-html: /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monoid-subclasses-0.4.3.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monoid-subclasses
version: 0.4.3.1
id: monoid-subclasses-0.4.3.1-KxZSRwmf8rR353MuGWEfhz
key: monoid-subclasses-0.4.3.1-KxZSRwmf8rR353MuGWEfhz
license: BSD3
copyright: (c) 2013-2016 Mario Blazevic
maintainer: Mario Blazevic <blamario@yahoo.com>
homepage: https://github.com/blamario/monoid-subclasses/
synopsis: Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.
category: Data, Algebra, Text
author: Mario Blazevic
exposed: True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.Null
    Data.Monoid.Textual Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.Concat Data.Monoid.Instances.Measured
    Data.Monoid.Instances.Positioned Data.Monoid.Instances.Stateful
abi: 2b55a2db9c683e4ec9a1db02971343d6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/monoid-subclasses-0.4.3.1
hs-libraries: HSmonoid-subclasses-0.4.3.1-KxZSRwmf8rR353MuGWEfhz
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    primes-0.2.1.0-K0eIDQpwpli2u6M20VlfZn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock
haddock-html: /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
